# vim: set ts=4 sw=4 et:
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/

Name:           x264
%define soname  135
%define svn     20130723
Version:        0.%{soname}svn%{svn}
Release:        3.1
License:        GPL-2.0+
Summary:        A free h264/avc encoder - encoder binary
Url:            http://developers.videolan.org/%{name}.html
Group:          Productivity/Multimedia/Video/Editors and Convertors
Source0:        ftp://ftp.videolan.org/pub/videolan/%{name}/snapshots/%{name}-snapshot-%{svn}-2245.tar.bz2
Patch:		%{name}-gpac-shared-library.patch
%if 0%{?suse_version} >= 1140
BuildRequires:	libffms2-devel
%endif
BuildRequires:	libgpac-devel
# resolve conflicts
%if 0%{?suse_version} <= 1140
%if ! 0%{?sles_version}
BuildRequires:  mozilla-js192
%endif
%endif
%if 0%{?suse_version} == 1210
BuildRequires:  mozilla-js
%endif
BuildRequires:  nasm
BuildRequires:  pkg-config
BuildRequires:  yasm >= 1.2.0
BuildRequires:  libffmpeg-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
x264 is a free library for encoding next-generation H264/AVC video
streams. The code is written from scratch by Laurent Aimar, Loren
Merritt, Eric Petit (OS X), Min Chen (vfw/asm), Justin Clay (vfw), Mans
Rullgard, Radek Czyz, Christian Heine (asm), Alex Izvorski (asm), and
Alex Wright. It is released under the terms of the GPL license. This
package contains a shared library and a commandline tool for encoding
H264 streams. This library is needed for mplayer/mencoder for H264
encoding support.

Encoder features:
- CAVLC/CABAC
- Multi-references
- Intra: all macroblock types (16x16, 8x8, and 4x4 with all predictions)
- Inter P: all partitions (from 16x16 down to 4x4)
- Inter B: partitions from 16x16 down to 8x8 (including skip/direct)
- Ratecontrol: constant quantizer, single or multipass ABR, optional VBV
- Scene cut detection
- Adaptive B-frame placement
- B-frames as references / arbitrary frame order
- 8x8 and 4x4 adaptive spatial transform
- Lossless mode
- Custom quantization matrices
- Parallel encoding of multiple slices (currently disabled)

Be aware that the x264 library is still in early development stage. The
command line tool x264 can handle only raw YUV 4:2:0 streams at the
moment so please use mencoder or another tool that supports x264 library
for all other file types.

%prep
%setup -q -n "%{name}-snapshot-%{svn}-2245"
%patch -p1
%define FAKE_BUILDDATE %(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i 's/__DATE__/"%{FAKE_BUILDDATE}"/' %{name}.c

%build
%configure --enable-pic --enable-visualize
make %{?_smp_mflags}

%install
%makeinstall

rm -rf "%{buildroot}%{_includedir}"
rm -rf "%{buildroot}%{_libdir}"

%files
%defattr(-,root,root)
%doc doc/*.txt
%attr(0755,root,root) %{_bindir}/%{name}

%changelog
* Fri Jul 26 2013 i@margueirte.su
- fix gpac detection.
* Fri Jul 26 2013 i@margueirte.su
- update version 20130723
* Thu Mar  7 2013 marguerite@opensuse.org
- fallback to 8-bit depth again.
  * A user said he still need 8-bit to use `baseline` profile
    for very old android phones.
* Sun Feb 24 2013 marguerite@opensuse.org
- update to version 20130224.
- enable 10-bit depth by default.
* Fri Nov  2 2012 i@margueirte.su
- selectively build with ffmpeg, ffms2 and gpac.
* Thu Nov  1 2012 pascal.bleser@opensuse.org
- only build the x264 binary, with ffmpeg support; the library now
  lives in the libx264 package to avoid cycles with ffmpeg (which
  requires libx264)
* Sat Sep 29 2012 Manfred.Tremmel@iiv.de
- update to snapshot 20120928
* Sat May 26 2012 Manfred.Tremmel@iiv.de
- update to snapshot 20120525
* Sat Apr 14 2012 Manfred.Tremmel@iiv.de
- update to snapshot 20120414
* Mon Mar 12 2012 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Added 32bit compatibility version (needed by
  gstreamer-0_10-plugins-ugly-orig-addon-32bit)
* Fri Jan 27 2012 Manfred.Tremmel@iiv.de
- update to snapshot 20120126
* Tue Dec 27 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20111226
* Fri Sep 23 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20111122
* Thu Sep  8 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20110907
* Thu Jun 23 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20110622
* Sat May 28 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20110527
* Sat Apr 23 2011 reddwarf@opensuse.org
- remove build timestamp
- remove execution permissions from library
* Sat Feb 26 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20110225
* Sun Jan 16 2011 Manfred.Tremmel@iiv.de
- update to snapshot 20110115
* Sun Oct 17 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20101016
* Sun Oct  3 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20101002
* Tue Jun 29 2010 ludwig.nussel@gmx.de
- require pkg-config
- link binary against shared library
* Wed Jun 16 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100615
* Tue May 18 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100517
* Mon Apr 26 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100425
  now able to create Blue Ray compatible h.264 streams
* Sat Apr  3 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100402
* Sun Feb 28 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100227
* Wed Feb 17 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100216
* Sat Feb  6 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100205
* Wed Jan 27 2010 Manfred.Tremmel@iiv.de
- rebuild because of no submit with the last build
* Sat Jan 23 2010 Manfred.Tremmel@iiv.de
- update to snapshot 20100122
* Sat Jan  2 2010 Manfred.Tremmel@iiv.de
- update to svn 20100101
* Tue Dec 15 2009 Manfred.Tremmel@iiv.de
- added a patch to fix broken ffmpeg defaults instead of aborting
* Fri Dec 11 2009 Manfred.Tremmel@iiv.de
- update to svn 20091211
* Mon Nov 23 2009 Manfred.Tremmel@iiv.de
- update to svn 20091123
* Tue Aug 25 2009 Manfred.Tremmel@iiv.de
- updated to snapshot 20090624
* Sat Jun 27 2009 Manfred.Tremmel@iiv.de
- updated to snapshot 20090627
* Sun May 10 2009 Manfred.Tremmel@iiv.de
- updated to snapshot 20090510
* Tue Mar 10 2009 Manfred.Tremmel@iiv.de
- updated to snapshot 20090310
* Sat Feb  7 2009 Manfred.Tremmel@iiv.de
- updated to snapshot 20090206
* Thu Nov  6 2008 Manfred.Tremmel@iiv.de
- updated to snapshot 20081105
* Sat Oct  4 2008 Manfred.Tremmel@iiv.de
- updated to snapshot 20081004
* Wed Sep 17 2008 Manfred.Tremmel@iiv.de
- updated to snapshot 20080917
* Thu Aug 14 2008 Manfred.Tremmel@iiv.de
- updated to snapshot 20080814
- recompile with new yasm version
* Sat Aug  9 2008 Manfred.Tremmel@iiv.de
- updated to snapshot 20080809
* Tue Jun 17 2008 Manfred.Tremmel@iiv.de
- updated to snapshot 20080617
- also included snapshot 20071225 lib for compatibility reasons
* Wed Apr 30 2008 guru@unixtech.be
- fixed file permissions, thanks to Christian Morales Vega <cmorve69@yahoo.es>
* Mon Dec 31 2007 guru@unixtech.be
- made Requires in main package require the exact version-release
- fixed License tag according to 10.3 packaging policies
- added Provides/Obsoletes for proper upgrading of x264=>libx264-devel
* Wed Dec 26 2007 leon@links2linux.de
- updated to snapshot 20071225
- changed the spec according to the new library policy, thanks Detlef
- changed the group according to SPC guidelines
* Mon Nov  6 2006 detlef@links2linux.de
- update to snapshot-20061031-2245
* Wed Nov  1 2006 leon@links2linux.de
- new release
* Wed Apr 26 2006 leon@links2linux.de
- updated to the newest tarball (to fix PPC compiling)
- match the new library revision (libx264.so.46)
* Tue Apr 18 2006 leon@links2linux.de
- updated to the newest tarball
- removed the syntax patch since it has been merged
- remove yasm from BuildRequires on x86
* Wed Mar 22 2006 henne@links2linux.de
- introduce a build section <:)
- full url for source
* Sat Mar 18 2006 leon@links2linux.de
- Initial release for packman.
